@@ -12,6 +12,9 @@ export function runAction(keybind: Keybind) {
         case "deafen":
             deafenToggle();
             break;
+        case "pushToTalk":
+            pushToTalk();
+            break;
         case "leaveCall":
             leaveCall();
             break;
@@ -85,6 +88,19 @@ export function leaveCall() {
     });
 }
 
+export function pushToTalk() {
+    console.log("[Keybind action] Push to talk");
+    mainWindows.forEach((window) => {
+        void window.webContents.executeJavaScript(`
+        window.shelter.flux.dispatcher.dispatch({
+            "type": "PUSH_TO_TALK_STATE_CHANGE",
+            "isActive": true,
+            "isPriority": false
+        })
+        `);
+    });
+}
+
 function navigateBack() {
     mainWindows.forEach((window) => {
         window.webContents.navigationHistory.goBack();
