@@ -218,7 +218,7 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
             }
         });
     }
-    initQuickCss(passedWindow);
+
     passedWindow.setTouchBar(mainTouchBar);
     app.on("open-url", (_event, url) => {
         navigateTo(passedWindow, url.replace("discord://-", ""));
@@ -297,7 +297,14 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
         setForceQuit(true);
     });
     passedWindow.webContents.session.webRequest.onBeforeRequest((details, callback) => {
-        if (details.url.includes("ws://127.0.0.1:")) return callback({ cancel: true });
+        // Lune Dev exceptions, https://github.com/uwu/shelter/blob/8d4ca369bf01abf348df9d4e111d534800c7a38c/packages/shelter/src/devmode/index.tsx#L24
+        if (
+            details.url.includes("ws://127.0.0.1:") &&
+            !details.url.includes("127.0.0.1:1211") &&
+            !details.url.includes("127.0.0.1:1112")
+        ) {
+            return callback({ cancel: true });
+        }
         return callback({});
     });
     passedWindow.on("focus", () => {
@@ -364,6 +371,12 @@ export function createWindow() {
         },
     };
     switch (getConfig("windowStyle")) {
+        case "default":
+            if (os.platform() === "win32") {
+                browserWindowOptions.titleBarStyle = "hidden";
+                browserWindowOptions.titleBarOverlay = false;
+            }
+            break;
         case "native":
             browserWindowOptions.frame = true;
             break;
@@ -372,7 +385,7 @@ export function createWindow() {
             browserWindowOptions.titleBarOverlay = {
                 color: getConfig("overlayButtonColor"),
                 symbolColor: "#99aab5",
-                height: 36,
+                height: 30,
             };
             browserWindowOptions.trafficLightPosition = {
                 x: 10,
