@@ -2,13 +2,15 @@ import path from "node:path";
 import { BrowserWindow, ipcMain } from "electron";
 import isDev from "electron-is-dev";
 import { getConfig } from "../common/config.js";
+import { getLang } from "../common/lang.js";
 
 export let splashWindow: BrowserWindow;
 export async function createSplashWindow(): Promise<void> {
+    if (getConfig("startMinimized")) return;
     splashWindow = new BrowserWindow({
         width: 300,
         height: 350,
-        title: "Legcord",
+        title: getLang("splash-title"),
         show: true,
         darkTheme: true,
         icon: getConfig("customIcon") ?? path.join(import.meta.dirname, "../", "/assets/desktop.png"),
